==============================
WebSocket Public API Reference
==============================

The following is an API reference of CoPrA generated from Python source code and docstrings.

.. warning::
   This is a *complete* reference of the *public* API of CoPrA.
   User code and applications should only rely on the public API, since internal APIs can (and will) change without any guarantees. Anything *not* listed here is considered a private API.



Module ``copra.websocket``
--------------------------

.. automodule:: copra.websocket
    
    .. autoclass:: Channel
        :members:
        :special-members: __init__
        
    .. autoclass:: Client
        :members:
        :special-members: __init__
